.. _api-ref:

*************
API reference
*************

.. note::

    Only APIs documented here are public and open for use by Mopidy
    extensions.


Concepts
========

.. toctree::

    architecture
    models


Basics
======

.. toctree::

    core
    frontend
    backend
    ext


Web/JavaScript
==============

.. toctree::

    http-server
    http
    js


Audio
=====

.. toctree::

    audio
    mixer


Utilities
=========

.. toctree::

    commands
    config
    httpclient
    zeroconf
